@@ -3,14 +3,14 @@ Main interface for lex-models service type definitions.
 
 Usage::
 
-    from mypy_boto3.lex_models.type_defs import CodeHookTypeDef
+    ```python
+    from mypy_boto3_lex_models.type_defs import BotAliasMetadataTypeDef
 
-    data: CodeHookTypeDef = {...}
+    data: BotAliasMetadataTypeDef = {...}
+    ```
 """
-from __future__ import annotations
-
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import Dict, List
 
 if sys.version_info >= (3, 8):
@@ -24,51 +24,60 @@ else:
 
 
 __all__ = (
+    "BotAliasMetadataTypeDef",
+    "BotChannelAssociationTypeDef",
+    "BotMetadataTypeDef",
+    "BuiltinIntentMetadataTypeDef",
+    "BuiltinIntentSlotTypeDef",
+    "BuiltinSlotTypeMetadataTypeDef",
     "CodeHookTypeDef",
-    "LogSettingsRequestTypeDef",
-    "ConversationLogsRequestTypeDef",
-    "IntentTypeDef",
-    "MessageTypeDef",
-    "PromptTypeDef",
-    "StatementTypeDef",
-    "CreateBotVersionResponseTypeDef",
+    "ConversationLogsResponseTypeDef",
+    "EnumerationValueTypeDef",
     "FollowUpPromptTypeDef",
     "FulfillmentActivityTypeDef",
-    "SlotTypeDef",
-    "CreateIntentVersionResponseTypeDef",
-    "EnumerationValueTypeDef",
-    "CreateSlotTypeVersionResponseTypeDef",
+    "InputContextTypeDef",
+    "IntentMetadataTypeDef",
+    "IntentTypeDef",
+    "KendraConfigurationTypeDef",
+    "LogSettingsRequestTypeDef",
     "LogSettingsResponseTypeDef",
-    "ConversationLogsResponseTypeDef",
+    "MessageTypeDef",
+    "OutputContextTypeDef",
+    "PromptTypeDef",
+    "SlotDefaultValueSpecTypeDef",
+    "SlotDefaultValueTypeDef",
+    "SlotTypeConfigurationTypeDef",
+    "SlotTypeDef",
+    "SlotTypeMetadataTypeDef",
+    "SlotTypeRegexConfigurationTypeDef",
+    "StatementTypeDef",
+    "TagTypeDef",
+    "UtteranceDataTypeDef",
+    "UtteranceListTypeDef",
+    "ConversationLogsRequestTypeDef",
+    "CreateBotVersionResponseTypeDef",
+    "CreateIntentVersionResponseTypeDef",
+    "CreateSlotTypeVersionResponseTypeDef",
     "GetBotAliasResponseTypeDef",
-    "BotAliasMetadataTypeDef",
     "GetBotAliasesResponseTypeDef",
     "GetBotChannelAssociationResponseTypeDef",
-    "BotChannelAssociationTypeDef",
     "GetBotChannelAssociationsResponseTypeDef",
     "GetBotResponseTypeDef",
-    "BotMetadataTypeDef",
     "GetBotVersionsResponseTypeDef",
     "GetBotsResponseTypeDef",
-    "BuiltinIntentSlotTypeDef",
     "GetBuiltinIntentResponseTypeDef",
-    "BuiltinIntentMetadataTypeDef",
     "GetBuiltinIntentsResponseTypeDef",
-    "BuiltinSlotTypeMetadataTypeDef",
     "GetBuiltinSlotTypesResponseTypeDef",
     "GetExportResponseTypeDef",
     "GetImportResponseTypeDef",
     "GetIntentResponseTypeDef",
-    "IntentMetadataTypeDef",
     "GetIntentVersionsResponseTypeDef",
     "GetIntentsResponseTypeDef",
     "GetSlotTypeResponseTypeDef",
-    "SlotTypeMetadataTypeDef",
     "GetSlotTypeVersionsResponseTypeDef",
     "GetSlotTypesResponseTypeDef",
-    "UtteranceDataTypeDef",
-    "UtteranceListTypeDef",
     "GetUtterancesViewResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
     "PutBotAliasResponseTypeDef",
     "PutBotResponseTypeDef",
@@ -77,211 +86,6 @@ __all__ = (
     "StartImportResponseTypeDef",
 )
 
-CodeHookTypeDef = TypedDict("CodeHookTypeDef", {"uri": str, "messageVersion": str})
-
-_RequiredLogSettingsRequestTypeDef = TypedDict(
-    "_RequiredLogSettingsRequestTypeDef",
-    {
-        "logType": Literal["AUDIO", "TEXT"],
-        "destination": Literal["CLOUDWATCH_LOGS", "S3"],
-        "resourceArn": str,
-    },
-)
-_OptionalLogSettingsRequestTypeDef = TypedDict(
-    "_OptionalLogSettingsRequestTypeDef", {"kmsKeyArn": str}, total=False
-)
-
-
-class LogSettingsRequestTypeDef(
-    _RequiredLogSettingsRequestTypeDef, _OptionalLogSettingsRequestTypeDef
-):
-    pass
-
-
-ConversationLogsRequestTypeDef = TypedDict(
-    "ConversationLogsRequestTypeDef",
-    {"logSettings": List[LogSettingsRequestTypeDef], "iamRoleArn": str},
-)
-
-IntentTypeDef = TypedDict("IntentTypeDef", {"intentName": str, "intentVersion": str})
-
-_RequiredMessageTypeDef = TypedDict(
-    "_RequiredMessageTypeDef",
-    {"contentType": Literal["PlainText", "SSML", "CustomPayload"], "content": str},
-)
-_OptionalMessageTypeDef = TypedDict("_OptionalMessageTypeDef", {"groupNumber": int}, total=False)
-
-
-class MessageTypeDef(_RequiredMessageTypeDef, _OptionalMessageTypeDef):
-    pass
-
-
-_RequiredPromptTypeDef = TypedDict(
-    "_RequiredPromptTypeDef", {"messages": List[MessageTypeDef], "maxAttempts": int}
-)
-_OptionalPromptTypeDef = TypedDict("_OptionalPromptTypeDef", {"responseCard": str}, total=False)
-
-
-class PromptTypeDef(_RequiredPromptTypeDef, _OptionalPromptTypeDef):
-    pass
-
-
-_RequiredStatementTypeDef = TypedDict(
-    "_RequiredStatementTypeDef", {"messages": List[MessageTypeDef]}
-)
-_OptionalStatementTypeDef = TypedDict(
-    "_OptionalStatementTypeDef", {"responseCard": str}, total=False
-)
-
-
-class StatementTypeDef(_RequiredStatementTypeDef, _OptionalStatementTypeDef):
-    pass
-
-
-CreateBotVersionResponseTypeDef = TypedDict(
-    "CreateBotVersionResponseTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "intents": List[IntentTypeDef],
-        "clarificationPrompt": PromptTypeDef,
-        "abortStatement": StatementTypeDef,
-        "status": Literal["BUILDING", "READY", "READY_BASIC_TESTING", "FAILED", "NOT_BUILT"],
-        "failureReason": str,
-        "lastUpdatedDate": datetime,
-        "createdDate": datetime,
-        "idleSessionTTLInSeconds": int,
-        "voiceId": str,
-        "checksum": str,
-        "version": str,
-        "locale": Literal["en-US", "en-GB", "de-DE"],
-        "childDirected": bool,
-        "detectSentiment": bool,
-    },
-    total=False,
-)
-
-FollowUpPromptTypeDef = TypedDict(
-    "FollowUpPromptTypeDef", {"prompt": PromptTypeDef, "rejectionStatement": StatementTypeDef}
-)
-
-_RequiredFulfillmentActivityTypeDef = TypedDict(
-    "_RequiredFulfillmentActivityTypeDef", {"type": Literal["ReturnIntent", "CodeHook"]}
-)
-_OptionalFulfillmentActivityTypeDef = TypedDict(
-    "_OptionalFulfillmentActivityTypeDef", {"codeHook": CodeHookTypeDef}, total=False
-)
-
-
-class FulfillmentActivityTypeDef(
-    _RequiredFulfillmentActivityTypeDef, _OptionalFulfillmentActivityTypeDef
-):
-    pass
-
-
-_RequiredSlotTypeDef = TypedDict(
-    "_RequiredSlotTypeDef", {"name": str, "slotConstraint": Literal["Required", "Optional"]}
-)
-_OptionalSlotTypeDef = TypedDict(
-    "_OptionalSlotTypeDef",
-    {
-        "description": str,
-        "slotType": str,
-        "slotTypeVersion": str,
-        "valueElicitationPrompt": PromptTypeDef,
-        "priority": int,
-        "sampleUtterances": List[str],
-        "responseCard": str,
-        "obfuscationSetting": Literal["NONE", "DEFAULT_OBFUSCATION"],
-    },
-    total=False,
-)
-
-
-class SlotTypeDef(_RequiredSlotTypeDef, _OptionalSlotTypeDef):
-    pass
-
-
-CreateIntentVersionResponseTypeDef = TypedDict(
-    "CreateIntentVersionResponseTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "slots": List[SlotTypeDef],
-        "sampleUtterances": List[str],
-        "confirmationPrompt": PromptTypeDef,
-        "rejectionStatement": StatementTypeDef,
-        "followUpPrompt": FollowUpPromptTypeDef,
-        "conclusionStatement": StatementTypeDef,
-        "dialogCodeHook": CodeHookTypeDef,
-        "fulfillmentActivity": FulfillmentActivityTypeDef,
-        "parentIntentSignature": str,
-        "lastUpdatedDate": datetime,
-        "createdDate": datetime,
-        "version": str,
-        "checksum": str,
-    },
-    total=False,
-)
-
-_RequiredEnumerationValueTypeDef = TypedDict("_RequiredEnumerationValueTypeDef", {"value": str})
-_OptionalEnumerationValueTypeDef = TypedDict(
-    "_OptionalEnumerationValueTypeDef", {"synonyms": List[str]}, total=False
-)
-
-
-class EnumerationValueTypeDef(_RequiredEnumerationValueTypeDef, _OptionalEnumerationValueTypeDef):
-    pass
-
-
-CreateSlotTypeVersionResponseTypeDef = TypedDict(
-    "CreateSlotTypeVersionResponseTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "enumerationValues": List[EnumerationValueTypeDef],
-        "lastUpdatedDate": datetime,
-        "createdDate": datetime,
-        "version": str,
-        "checksum": str,
-        "valueSelectionStrategy": Literal["ORIGINAL_VALUE", "TOP_RESOLUTION"],
-    },
-    total=False,
-)
-
-LogSettingsResponseTypeDef = TypedDict(
-    "LogSettingsResponseTypeDef",
-    {
-        "logType": Literal["AUDIO", "TEXT"],
-        "destination": Literal["CLOUDWATCH_LOGS", "S3"],
-        "kmsKeyArn": str,
-        "resourceArn": str,
-        "resourcePrefix": str,
-    },
-    total=False,
-)
-
-ConversationLogsResponseTypeDef = TypedDict(
-    "ConversationLogsResponseTypeDef",
-    {"logSettings": List[LogSettingsResponseTypeDef], "iamRoleArn": str},
-    total=False,
-)
-
-GetBotAliasResponseTypeDef = TypedDict(
-    "GetBotAliasResponseTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "botVersion": str,
-        "botName": str,
-        "lastUpdatedDate": datetime,
-        "createdDate": datetime,
-        "checksum": str,
-        "conversationLogs": ConversationLogsResponseTypeDef,
-    },
-    total=False,
-)
-
 BotAliasMetadataTypeDef = TypedDict(
     "BotAliasMetadataTypeDef",
     {
@@ -292,29 +96,7 @@ BotAliasMetadataTypeDef = TypedDict(
         "lastUpdatedDate": datetime,
         "createdDate": datetime,
         "checksum": str,
-        "conversationLogs": ConversationLogsResponseTypeDef,
-    },
-    total=False,
-)
-
-GetBotAliasesResponseTypeDef = TypedDict(
-    "GetBotAliasesResponseTypeDef",
-    {"BotAliases": List[BotAliasMetadataTypeDef], "nextToken": str},
-    total=False,
-)
-
-GetBotChannelAssociationResponseTypeDef = TypedDict(
-    "GetBotChannelAssociationResponseTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "botAlias": str,
-        "botName": str,
-        "createdDate": datetime,
-        "type": Literal["Facebook", "Slack", "Twilio-Sms", "Kik"],
-        "botConfiguration": Dict[str, str],
-        "status": Literal["IN_PROGRESS", "CREATED", "FAILED"],
-        "failureReason": str,
+        "conversationLogs": "ConversationLogsResponseTypeDef",
     },
     total=False,
 )
@@ -335,35 +117,6 @@ BotChannelAssociationTypeDef = TypedDict(
     total=False,
 )
 
-GetBotChannelAssociationsResponseTypeDef = TypedDict(
-    "GetBotChannelAssociationsResponseTypeDef",
-    {"botChannelAssociations": List[BotChannelAssociationTypeDef], "nextToken": str},
-    total=False,
-)
-
-GetBotResponseTypeDef = TypedDict(
-    "GetBotResponseTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "intents": List[IntentTypeDef],
-        "clarificationPrompt": PromptTypeDef,
-        "abortStatement": StatementTypeDef,
-        "status": Literal["BUILDING", "READY", "READY_BASIC_TESTING", "FAILED", "NOT_BUILT"],
-        "failureReason": str,
-        "lastUpdatedDate": datetime,
-        "createdDate": datetime,
-        "idleSessionTTLInSeconds": int,
-        "voiceId": str,
-        "checksum": str,
-        "version": str,
-        "locale": Literal["en-US", "en-GB", "de-DE"],
-        "childDirected": bool,
-        "detectSentiment": bool,
-    },
-    total=False,
-)
-
 BotMetadataTypeDef = TypedDict(
     "BotMetadataTypeDef",
     {
@@ -377,49 +130,459 @@ BotMetadataTypeDef = TypedDict(
     total=False,
 )
 
+BuiltinIntentMetadataTypeDef = TypedDict(
+    "BuiltinIntentMetadataTypeDef",
+    {
+        "signature": str,
+        "supportedLocales": List[
+            Literal[
+                "de-DE",
+                "en-AU",
+                "en-GB",
+                "en-US",
+                "es-419",
+                "es-ES",
+                "es-US",
+                "fr-FR",
+                "fr-CA",
+                "it-IT",
+            ]
+        ],
+    },
+    total=False,
+)
+
+BuiltinIntentSlotTypeDef = TypedDict("BuiltinIntentSlotTypeDef", {"name": str}, total=False)
+
+BuiltinSlotTypeMetadataTypeDef = TypedDict(
+    "BuiltinSlotTypeMetadataTypeDef",
+    {
+        "signature": str,
+        "supportedLocales": List[
+            Literal[
+                "de-DE",
+                "en-AU",
+                "en-GB",
+                "en-US",
+                "es-419",
+                "es-ES",
+                "es-US",
+                "fr-FR",
+                "fr-CA",
+                "it-IT",
+            ]
+        ],
+    },
+    total=False,
+)
+
+CodeHookTypeDef = TypedDict("CodeHookTypeDef", {"uri": str, "messageVersion": str})
+
+ConversationLogsResponseTypeDef = TypedDict(
+    "ConversationLogsResponseTypeDef",
+    {"logSettings": List["LogSettingsResponseTypeDef"], "iamRoleArn": str},
+    total=False,
+)
+
+_RequiredEnumerationValueTypeDef = TypedDict("_RequiredEnumerationValueTypeDef", {"value": str})
+_OptionalEnumerationValueTypeDef = TypedDict(
+    "_OptionalEnumerationValueTypeDef", {"synonyms": List[str]}, total=False
+)
+
+
+class EnumerationValueTypeDef(_RequiredEnumerationValueTypeDef, _OptionalEnumerationValueTypeDef):
+    pass
+
+
+FollowUpPromptTypeDef = TypedDict(
+    "FollowUpPromptTypeDef", {"prompt": "PromptTypeDef", "rejectionStatement": "StatementTypeDef"}
+)
+
+_RequiredFulfillmentActivityTypeDef = TypedDict(
+    "_RequiredFulfillmentActivityTypeDef", {"type": Literal["ReturnIntent", "CodeHook"]}
+)
+_OptionalFulfillmentActivityTypeDef = TypedDict(
+    "_OptionalFulfillmentActivityTypeDef", {"codeHook": "CodeHookTypeDef"}, total=False
+)
+
+
+class FulfillmentActivityTypeDef(
+    _RequiredFulfillmentActivityTypeDef, _OptionalFulfillmentActivityTypeDef
+):
+    pass
+
+
+InputContextTypeDef = TypedDict("InputContextTypeDef", {"name": str})
+
+IntentMetadataTypeDef = TypedDict(
+    "IntentMetadataTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "lastUpdatedDate": datetime,
+        "createdDate": datetime,
+        "version": str,
+    },
+    total=False,
+)
+
+IntentTypeDef = TypedDict("IntentTypeDef", {"intentName": str, "intentVersion": str})
+
+_RequiredKendraConfigurationTypeDef = TypedDict(
+    "_RequiredKendraConfigurationTypeDef", {"kendraIndex": str, "role": str}
+)
+_OptionalKendraConfigurationTypeDef = TypedDict(
+    "_OptionalKendraConfigurationTypeDef", {"queryFilterString": str}, total=False
+)
+
+
+class KendraConfigurationTypeDef(
+    _RequiredKendraConfigurationTypeDef, _OptionalKendraConfigurationTypeDef
+):
+    pass
+
+
+_RequiredLogSettingsRequestTypeDef = TypedDict(
+    "_RequiredLogSettingsRequestTypeDef",
+    {
+        "logType": Literal["AUDIO", "TEXT"],
+        "destination": Literal["CLOUDWATCH_LOGS", "S3"],
+        "resourceArn": str,
+    },
+)
+_OptionalLogSettingsRequestTypeDef = TypedDict(
+    "_OptionalLogSettingsRequestTypeDef", {"kmsKeyArn": str}, total=False
+)
+
+
+class LogSettingsRequestTypeDef(
+    _RequiredLogSettingsRequestTypeDef, _OptionalLogSettingsRequestTypeDef
+):
+    pass
+
+
+LogSettingsResponseTypeDef = TypedDict(
+    "LogSettingsResponseTypeDef",
+    {
+        "logType": Literal["AUDIO", "TEXT"],
+        "destination": Literal["CLOUDWATCH_LOGS", "S3"],
+        "kmsKeyArn": str,
+        "resourceArn": str,
+        "resourcePrefix": str,
+    },
+    total=False,
+)
+
+_RequiredMessageTypeDef = TypedDict(
+    "_RequiredMessageTypeDef",
+    {"contentType": Literal["PlainText", "SSML", "CustomPayload"], "content": str},
+)
+_OptionalMessageTypeDef = TypedDict("_OptionalMessageTypeDef", {"groupNumber": int}, total=False)
+
+
+class MessageTypeDef(_RequiredMessageTypeDef, _OptionalMessageTypeDef):
+    pass
+
+
+OutputContextTypeDef = TypedDict(
+    "OutputContextTypeDef", {"name": str, "timeToLiveInSeconds": int, "turnsToLive": int}
+)
+
+_RequiredPromptTypeDef = TypedDict(
+    "_RequiredPromptTypeDef", {"messages": List["MessageTypeDef"], "maxAttempts": int}
+)
+_OptionalPromptTypeDef = TypedDict("_OptionalPromptTypeDef", {"responseCard": str}, total=False)
+
+
+class PromptTypeDef(_RequiredPromptTypeDef, _OptionalPromptTypeDef):
+    pass
+
+
+SlotDefaultValueSpecTypeDef = TypedDict(
+    "SlotDefaultValueSpecTypeDef", {"defaultValueList": List["SlotDefaultValueTypeDef"]}
+)
+
+SlotDefaultValueTypeDef = TypedDict("SlotDefaultValueTypeDef", {"defaultValue": str})
+
+SlotTypeConfigurationTypeDef = TypedDict(
+    "SlotTypeConfigurationTypeDef",
+    {"regexConfiguration": "SlotTypeRegexConfigurationTypeDef"},
+    total=False,
+)
+
+_RequiredSlotTypeDef = TypedDict(
+    "_RequiredSlotTypeDef", {"name": str, "slotConstraint": Literal["Required", "Optional"]}
+)
+_OptionalSlotTypeDef = TypedDict(
+    "_OptionalSlotTypeDef",
+    {
+        "description": str,
+        "slotType": str,
+        "slotTypeVersion": str,
+        "valueElicitationPrompt": "PromptTypeDef",
+        "priority": int,
+        "sampleUtterances": List[str],
+        "responseCard": str,
+        "obfuscationSetting": Literal["NONE", "DEFAULT_OBFUSCATION"],
+        "defaultValueSpec": "SlotDefaultValueSpecTypeDef",
+    },
+    total=False,
+)
+
+
+class SlotTypeDef(_RequiredSlotTypeDef, _OptionalSlotTypeDef):
+    pass
+
+
+SlotTypeMetadataTypeDef = TypedDict(
+    "SlotTypeMetadataTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "lastUpdatedDate": datetime,
+        "createdDate": datetime,
+        "version": str,
+    },
+    total=False,
+)
+
+SlotTypeRegexConfigurationTypeDef = TypedDict("SlotTypeRegexConfigurationTypeDef", {"pattern": str})
+
+_RequiredStatementTypeDef = TypedDict(
+    "_RequiredStatementTypeDef", {"messages": List["MessageTypeDef"]}
+)
+_OptionalStatementTypeDef = TypedDict(
+    "_OptionalStatementTypeDef", {"responseCard": str}, total=False
+)
+
+
+class StatementTypeDef(_RequiredStatementTypeDef, _OptionalStatementTypeDef):
+    pass
+
+
+TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str})
+
+UtteranceDataTypeDef = TypedDict(
+    "UtteranceDataTypeDef",
+    {
+        "utteranceString": str,
+        "count": int,
+        "distinctUsers": int,
+        "firstUtteredDate": datetime,
+        "lastUtteredDate": datetime,
+    },
+    total=False,
+)
+
+UtteranceListTypeDef = TypedDict(
+    "UtteranceListTypeDef",
+    {"botVersion": str, "utterances": List["UtteranceDataTypeDef"]},
+    total=False,
+)
+
+ConversationLogsRequestTypeDef = TypedDict(
+    "ConversationLogsRequestTypeDef",
+    {"logSettings": List["LogSettingsRequestTypeDef"], "iamRoleArn": str},
+)
+
+CreateBotVersionResponseTypeDef = TypedDict(
+    "CreateBotVersionResponseTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "intents": List["IntentTypeDef"],
+        "clarificationPrompt": "PromptTypeDef",
+        "abortStatement": "StatementTypeDef",
+        "status": Literal["BUILDING", "READY", "READY_BASIC_TESTING", "FAILED", "NOT_BUILT"],
+        "failureReason": str,
+        "lastUpdatedDate": datetime,
+        "createdDate": datetime,
+        "idleSessionTTLInSeconds": int,
+        "voiceId": str,
+        "checksum": str,
+        "version": str,
+        "locale": Literal[
+            "de-DE",
+            "en-AU",
+            "en-GB",
+            "en-US",
+            "es-419",
+            "es-ES",
+            "es-US",
+            "fr-FR",
+            "fr-CA",
+            "it-IT",
+        ],
+        "childDirected": bool,
+        "enableModelImprovements": bool,
+        "detectSentiment": bool,
+    },
+    total=False,
+)
+
+CreateIntentVersionResponseTypeDef = TypedDict(
+    "CreateIntentVersionResponseTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "slots": List["SlotTypeDef"],
+        "sampleUtterances": List[str],
+        "confirmationPrompt": "PromptTypeDef",
+        "rejectionStatement": "StatementTypeDef",
+        "followUpPrompt": "FollowUpPromptTypeDef",
+        "conclusionStatement": "StatementTypeDef",
+        "dialogCodeHook": "CodeHookTypeDef",
+        "fulfillmentActivity": "FulfillmentActivityTypeDef",
+        "parentIntentSignature": str,
+        "lastUpdatedDate": datetime,
+        "createdDate": datetime,
+        "version": str,
+        "checksum": str,
+        "kendraConfiguration": "KendraConfigurationTypeDef",
+        "inputContexts": List["InputContextTypeDef"],
+        "outputContexts": List["OutputContextTypeDef"],
+    },
+    total=False,
+)
+
+CreateSlotTypeVersionResponseTypeDef = TypedDict(
+    "CreateSlotTypeVersionResponseTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "enumerationValues": List["EnumerationValueTypeDef"],
+        "lastUpdatedDate": datetime,
+        "createdDate": datetime,
+        "version": str,
+        "checksum": str,
+        "valueSelectionStrategy": Literal["ORIGINAL_VALUE", "TOP_RESOLUTION"],
+        "parentSlotTypeSignature": str,
+        "slotTypeConfigurations": List["SlotTypeConfigurationTypeDef"],
+    },
+    total=False,
+)
+
+GetBotAliasResponseTypeDef = TypedDict(
+    "GetBotAliasResponseTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "botVersion": str,
+        "botName": str,
+        "lastUpdatedDate": datetime,
+        "createdDate": datetime,
+        "checksum": str,
+        "conversationLogs": "ConversationLogsResponseTypeDef",
+    },
+    total=False,
+)
+
+GetBotAliasesResponseTypeDef = TypedDict(
+    "GetBotAliasesResponseTypeDef",
+    {"BotAliases": List["BotAliasMetadataTypeDef"], "nextToken": str},
+    total=False,
+)
+
+GetBotChannelAssociationResponseTypeDef = TypedDict(
+    "GetBotChannelAssociationResponseTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "botAlias": str,
+        "botName": str,
+        "createdDate": datetime,
+        "type": Literal["Facebook", "Slack", "Twilio-Sms", "Kik"],
+        "botConfiguration": Dict[str, str],
+        "status": Literal["IN_PROGRESS", "CREATED", "FAILED"],
+        "failureReason": str,
+    },
+    total=False,
+)
+
+GetBotChannelAssociationsResponseTypeDef = TypedDict(
+    "GetBotChannelAssociationsResponseTypeDef",
+    {"botChannelAssociations": List["BotChannelAssociationTypeDef"], "nextToken": str},
+    total=False,
+)
+
+GetBotResponseTypeDef = TypedDict(
+    "GetBotResponseTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "intents": List["IntentTypeDef"],
+        "enableModelImprovements": bool,
+        "nluIntentConfidenceThreshold": float,
+        "clarificationPrompt": "PromptTypeDef",
+        "abortStatement": "StatementTypeDef",
+        "status": Literal["BUILDING", "READY", "READY_BASIC_TESTING", "FAILED", "NOT_BUILT"],
+        "failureReason": str,
+        "lastUpdatedDate": datetime,
+        "createdDate": datetime,
+        "idleSessionTTLInSeconds": int,
+        "voiceId": str,
+        "checksum": str,
+        "version": str,
+        "locale": Literal[
+            "de-DE",
+            "en-AU",
+            "en-GB",
+            "en-US",
+            "es-419",
+            "es-ES",
+            "es-US",
+            "fr-FR",
+            "fr-CA",
+            "it-IT",
+        ],
+        "childDirected": bool,
+        "detectSentiment": bool,
+    },
+    total=False,
+)
+
 GetBotVersionsResponseTypeDef = TypedDict(
     "GetBotVersionsResponseTypeDef",
-    {"bots": List[BotMetadataTypeDef], "nextToken": str},
+    {"bots": List["BotMetadataTypeDef"], "nextToken": str},
     total=False,
 )
 
 GetBotsResponseTypeDef = TypedDict(
-    "GetBotsResponseTypeDef", {"bots": List[BotMetadataTypeDef], "nextToken": str}, total=False
+    "GetBotsResponseTypeDef", {"bots": List["BotMetadataTypeDef"], "nextToken": str}, total=False
 )
 
-BuiltinIntentSlotTypeDef = TypedDict("BuiltinIntentSlotTypeDef", {"name": str}, total=False)
-
 GetBuiltinIntentResponseTypeDef = TypedDict(
     "GetBuiltinIntentResponseTypeDef",
     {
         "signature": str,
-        "supportedLocales": List[Literal["en-US", "en-GB", "de-DE"]],
-        "slots": List[BuiltinIntentSlotTypeDef],
+        "supportedLocales": List[
+            Literal[
+                "de-DE",
+                "en-AU",
+                "en-GB",
+                "en-US",
+                "es-419",
+                "es-ES",
+                "es-US",
+                "fr-FR",
+                "fr-CA",
+                "it-IT",
+            ]
+        ],
+        "slots": List["BuiltinIntentSlotTypeDef"],
     },
     total=False,
 )
 
-BuiltinIntentMetadataTypeDef = TypedDict(
-    "BuiltinIntentMetadataTypeDef",
-    {"signature": str, "supportedLocales": List[Literal["en-US", "en-GB", "de-DE"]]},
-    total=False,
-)
-
 GetBuiltinIntentsResponseTypeDef = TypedDict(
     "GetBuiltinIntentsResponseTypeDef",
-    {"intents": List[BuiltinIntentMetadataTypeDef], "nextToken": str},
-    total=False,
-)
-
-BuiltinSlotTypeMetadataTypeDef = TypedDict(
-    "BuiltinSlotTypeMetadataTypeDef",
-    {"signature": str, "supportedLocales": List[Literal["en-US", "en-GB", "de-DE"]]},
+    {"intents": List["BuiltinIntentMetadataTypeDef"], "nextToken": str},
     total=False,
 )
 
 GetBuiltinSlotTypesResponseTypeDef = TypedDict(
     "GetBuiltinSlotTypesResponseTypeDef",
-    {"slotTypes": List[BuiltinSlotTypeMetadataTypeDef], "nextToken": str},
+    {"slotTypes": List["BuiltinSlotTypeMetadataTypeDef"], "nextToken": str},
     total=False,
 )
 
@@ -456,44 +619,35 @@ GetIntentResponseTypeDef = TypedDict(
     {
         "name": str,
         "description": str,
-        "slots": List[SlotTypeDef],
+        "slots": List["SlotTypeDef"],
         "sampleUtterances": List[str],
-        "confirmationPrompt": PromptTypeDef,
-        "rejectionStatement": StatementTypeDef,
-        "followUpPrompt": FollowUpPromptTypeDef,
-        "conclusionStatement": StatementTypeDef,
-        "dialogCodeHook": CodeHookTypeDef,
-        "fulfillmentActivity": FulfillmentActivityTypeDef,
+        "confirmationPrompt": "PromptTypeDef",
+        "rejectionStatement": "StatementTypeDef",
+        "followUpPrompt": "FollowUpPromptTypeDef",
+        "conclusionStatement": "StatementTypeDef",
+        "dialogCodeHook": "CodeHookTypeDef",
+        "fulfillmentActivity": "FulfillmentActivityTypeDef",
         "parentIntentSignature": str,
         "lastUpdatedDate": datetime,
         "createdDate": datetime,
         "version": str,
         "checksum": str,
-    },
-    total=False,
-)
-
-IntentMetadataTypeDef = TypedDict(
-    "IntentMetadataTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "lastUpdatedDate": datetime,
-        "createdDate": datetime,
-        "version": str,
+        "kendraConfiguration": "KendraConfigurationTypeDef",
+        "inputContexts": List["InputContextTypeDef"],
+        "outputContexts": List["OutputContextTypeDef"],
     },
     total=False,
 )
 
 GetIntentVersionsResponseTypeDef = TypedDict(
     "GetIntentVersionsResponseTypeDef",
-    {"intents": List[IntentMetadataTypeDef], "nextToken": str},
+    {"intents": List["IntentMetadataTypeDef"], "nextToken": str},
     total=False,
 )
 
 GetIntentsResponseTypeDef = TypedDict(
     "GetIntentsResponseTypeDef",
-    {"intents": List[IntentMetadataTypeDef], "nextToken": str},
+    {"intents": List["IntentMetadataTypeDef"], "nextToken": str},
     total=False,
 )
 
@@ -502,64 +656,40 @@ GetSlotTypeResponseTypeDef = TypedDict(
     {
         "name": str,
         "description": str,
-        "enumerationValues": List[EnumerationValueTypeDef],
+        "enumerationValues": List["EnumerationValueTypeDef"],
         "lastUpdatedDate": datetime,
         "createdDate": datetime,
         "version": str,
         "checksum": str,
         "valueSelectionStrategy": Literal["ORIGINAL_VALUE", "TOP_RESOLUTION"],
-    },
-    total=False,
-)
-
-SlotTypeMetadataTypeDef = TypedDict(
-    "SlotTypeMetadataTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "lastUpdatedDate": datetime,
-        "createdDate": datetime,
-        "version": str,
+        "parentSlotTypeSignature": str,
+        "slotTypeConfigurations": List["SlotTypeConfigurationTypeDef"],
     },
     total=False,
 )
 
 GetSlotTypeVersionsResponseTypeDef = TypedDict(
     "GetSlotTypeVersionsResponseTypeDef",
-    {"slotTypes": List[SlotTypeMetadataTypeDef], "nextToken": str},
+    {"slotTypes": List["SlotTypeMetadataTypeDef"], "nextToken": str},
     total=False,
 )
 
 GetSlotTypesResponseTypeDef = TypedDict(
     "GetSlotTypesResponseTypeDef",
-    {"slotTypes": List[SlotTypeMetadataTypeDef], "nextToken": str},
-    total=False,
-)
-
-UtteranceDataTypeDef = TypedDict(
-    "UtteranceDataTypeDef",
-    {
-        "utteranceString": str,
-        "count": int,
-        "distinctUsers": int,
-        "firstUtteredDate": datetime,
-        "lastUtteredDate": datetime,
-    },
-    total=False,
-)
-
-UtteranceListTypeDef = TypedDict(
-    "UtteranceListTypeDef",
-    {"botVersion": str, "utterances": List[UtteranceDataTypeDef]},
+    {"slotTypes": List["SlotTypeMetadataTypeDef"], "nextToken": str},
     total=False,
 )
 
 GetUtterancesViewResponseTypeDef = TypedDict(
     "GetUtterancesViewResponseTypeDef",
-    {"botName": str, "utterances": List[UtteranceListTypeDef]},
+    {"botName": str, "utterances": List["UtteranceListTypeDef"]},
     total=False,
 )
 
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef", {"tags": List["TagTypeDef"]}, total=False
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
@@ -574,7 +704,8 @@ PutBotAliasResponseTypeDef = TypedDict(
         "lastUpdatedDate": datetime,
         "createdDate": datetime,
         "checksum": str,
-        "conversationLogs": ConversationLogsResponseTypeDef,
+        "conversationLogs": "ConversationLogsResponseTypeDef",
+        "tags": List["TagTypeDef"],
     },
     total=False,
 )
@@ -584,9 +715,11 @@ PutBotResponseTypeDef = TypedDict(
     {
         "name": str,
         "description": str,
-        "intents": List[IntentTypeDef],
-        "clarificationPrompt": PromptTypeDef,
-        "abortStatement": StatementTypeDef,
+        "intents": List["IntentTypeDef"],
+        "enableModelImprovements": bool,
+        "nluIntentConfidenceThreshold": float,
+        "clarificationPrompt": "PromptTypeDef",
+        "abortStatement": "StatementTypeDef",
         "status": Literal["BUILDING", "READY", "READY_BASIC_TESTING", "FAILED", "NOT_BUILT"],
         "failureReason": str,
         "lastUpdatedDate": datetime,
@@ -595,10 +728,22 @@ PutBotResponseTypeDef = TypedDict(
         "voiceId": str,
         "checksum": str,
         "version": str,
-        "locale": Literal["en-US", "en-GB", "de-DE"],
+        "locale": Literal[
+            "de-DE",
+            "en-AU",
+            "en-GB",
+            "en-US",
+            "es-419",
+            "es-ES",
+            "es-US",
+            "fr-FR",
+            "fr-CA",
+            "it-IT",
+        ],
         "childDirected": bool,
         "createVersion": bool,
         "detectSentiment": bool,
+        "tags": List["TagTypeDef"],
     },
     total=False,
 )
@@ -608,20 +753,23 @@ PutIntentResponseTypeDef = TypedDict(
     {
         "name": str,
         "description": str,
-        "slots": List[SlotTypeDef],
+        "slots": List["SlotTypeDef"],
         "sampleUtterances": List[str],
-        "confirmationPrompt": PromptTypeDef,
-        "rejectionStatement": StatementTypeDef,
-        "followUpPrompt": FollowUpPromptTypeDef,
-        "conclusionStatement": StatementTypeDef,
-        "dialogCodeHook": CodeHookTypeDef,
-        "fulfillmentActivity": FulfillmentActivityTypeDef,
+        "confirmationPrompt": "PromptTypeDef",
+        "rejectionStatement": "StatementTypeDef",
+        "followUpPrompt": "FollowUpPromptTypeDef",
+        "conclusionStatement": "StatementTypeDef",
+        "dialogCodeHook": "CodeHookTypeDef",
+        "fulfillmentActivity": "FulfillmentActivityTypeDef",
         "parentIntentSignature": str,
         "lastUpdatedDate": datetime,
         "createdDate": datetime,
         "version": str,
         "checksum": str,
         "createVersion": bool,
+        "kendraConfiguration": "KendraConfigurationTypeDef",
+        "inputContexts": List["InputContextTypeDef"],
+        "outputContexts": List["OutputContextTypeDef"],
     },
     total=False,
 )
@@ -631,13 +779,15 @@ PutSlotTypeResponseTypeDef = TypedDict(
     {
         "name": str,
         "description": str,
-        "enumerationValues": List[EnumerationValueTypeDef],
+        "enumerationValues": List["EnumerationValueTypeDef"],
         "lastUpdatedDate": datetime,
         "createdDate": datetime,
         "version": str,
         "checksum": str,
         "valueSelectionStrategy": Literal["ORIGINAL_VALUE", "TOP_RESOLUTION"],
         "createVersion": bool,
+        "parentSlotTypeSignature": str,
+        "slotTypeConfigurations": List["SlotTypeConfigurationTypeDef"],
     },
     total=False,
 )
@@ -650,6 +800,7 @@ StartImportResponseTypeDef = TypedDict(
         "mergeStrategy": Literal["OVERWRITE_LATEST", "FAIL_ON_CONFLICT"],
         "importId": str,
         "importStatus": Literal["IN_PROGRESS", "COMPLETE", "FAILED"],
+        "tags": List["TagTypeDef"],
         "createdDate": datetime,
     },
     total=False,
